@@ -36,7 +36,7 @@ public:
     Q_ENUM(FilterType)
 
     FilterType type;
-    std::variant<QString, QVector<CategoryFilter>> value;
+    std::variant<QString, QList<CategoryFilter>> value;
 
     bool operator==(const CategoryFilter &other) const;
     bool operator!=(const CategoryFilter &other) const
@@ -51,8 +51,8 @@ class DISCOVERCOMMON_EXPORT Category : public QObject
 public:
     Q_PROPERTY(QString name READ name NOTIFY nameChanged)
     Q_PROPERTY(QString icon READ icon CONSTANT)
-    Q_PROPERTY(QObject *parent READ parent CONSTANT)
     Q_PROPERTY(QVariantList subcategories READ subCategoriesVariant NOTIFY subCategoriesChanged)
+    Q_PROPERTY(bool visible READ isVisible NOTIFY visibleChanged)
 
     // Whether to apply localization during parsing.
     enum class Localization {
@@ -61,14 +61,21 @@ public:
         Force, /* < Use localization even when it'd break something (only use this for tests!) */
     };
 
-    explicit Category(QSet<QString> pluginNames, QObject *parent = nullptr);
+    // The type of package this category contains.
+    enum class Type {
+        Addon, /* < Category contains Plasma addons */
+        Driver, /* < Category contains hardware drivers */
+        Package, /* < Category contains regular packages */
+    };
+
+    explicit Category(QSet<QString> pluginNames, const std::shared_ptr<Category> &parent = {});
 
     Category(const QString &name,
              const QString &iconName,
              const CategoryFilter &filters,
              const QSet<QString> &pluginName,
-             const QVector<Category *> &subCategories,
-             bool isAddons);
+             const QList<std::shared_ptr<Category>> &subCategories,
+             Type type = Type::Package);
     ~Category() override;
 
     QString name() const;
@@ -78,22 +85,22 @@ public:
     QString icon() const;
     void setFilter(const CategoryFilter &filter);
     CategoryFilter filter() const;
-    const QVector<Category *> &subCategories() const;
+    const QList<std::shared_ptr<Category>> &subCategories() const;
     QVariantList subCategoriesVariant() const;
 
-    static void sortCategories(QVector<Category *> &cats);
-    static void addSubcategory(QVector<Category *> &cats, Category *cat);
+    static void sortCategories(QList<std::shared_ptr<Category>> &cats);
+    static void addSubcategory(QList<std::shared_ptr<Category>> &cats, const std::shared_ptr<Category> &cat);
     /**
      * Add a subcategory to this category. This function should only
      * be used during the initialisation stage, before adding the local
      * root category to the global root category model.
      */
-    void addSubcategory(Category *cat);
+    void addSubcategory(const std::shared_ptr<Category> &cat);
     void parseData(const QString &path, QXmlStreamReader *xml, Localization localization);
     bool blacklistPlugins(const QSet<QString> &pluginName);
-    bool isAddons() const
+    Type type() const
     {
-        return m_isAddons;
+        return m_type;
     }
     qint8 priority() const
     {
@@ -101,34 +108,73 @@ public:
     }
     bool matchesCategoryName(const QString &name) const;
 
-    Q_SCRIPTABLE bool contains(Category *cat) const;
+    /**
+     * @returns whether the category ought to be listed.
+     *
+     * It can be disabled passing <OnlyShowIn> with a vale differing from
+     * XDG_CURRENT_DESKTOP environment variable.
+     */
+    bool isVisible() const
+    {
+        return m_visible;
+    }
+
+    Q_SCRIPTABLE bool contains(const std::shared_ptr<Category> &cat) const;
     Q_SCRIPTABLE bool contains(const QVariantList &cats) const;
 
-    static bool categoryLessThan(Category *c1, const Category *c2);
-    static bool blacklistPluginsInVector(const QSet<QString> &pluginNames, QVector<Category *> &subCategories);
+    static bool categoryLessThan(const std::shared_ptr<Category> &c1, const std::shared_ptr<Category> &c2);
+    static bool blacklistPluginsInVector(const QSet<QString> &pluginNames, QList<std::shared_ptr<Category>> &subCategories);
 
     QStringList involvedCategories() const;
     QString untranslatedName() const
     {
         return m_untranslatedName;
     }
-    [[nodiscard]] static std::optional<QString> duplicatedNamesAsStringNested(const QList<Category *> &categories);
+    [[nodiscard]] static std::optional<QString> duplicatedNamesAsStringNested(const QList<std::shared_ptr<Category>> &categories);
+
+    std::shared_ptr<Category> parentCategory() const
+    {
+        return m_parentCategory;
+    }
+
+    void hide()
+    {
+        if (m_hide) {
+            return;
+        }
+        m_hide = true;
+        m_visible = false;
+        Q_EMIT visibleChanged();
+    }
 
 Q_SIGNALS:
     void subCategoriesChanged();
     void nameChanged();
+    void visibleChanged();
 
 private:
+    // disable the QObject parent business
+    QObject *parent() const;
+    void setParent(QObject *);
+
     void setNameMembers(const QString &name, Localization localization);
     QString m_name;
     QString m_untranslatedName;
     QString m_iconString;
     CategoryFilter m_filter;
-    QVector<Category *> m_subCategories;
+    QList<std::shared_ptr<Category>> m_subCategories;
 
     CategoryFilter parseIncludes(QXmlStreamReader *xml);
     QSet<QString> m_plugins;
-    bool m_isAddons = false;
+    Type m_type;
+    bool m_hide = false;
     qint8 m_priority = 0;
     QTimer *m_subCategoriesChanged;
+    bool m_visible = true;
+    std::shared_ptr<Category> m_parentCategory;
 };
+
+Q_DECLARE_SMART_POINTER_METATYPE(std::shared_ptr)
+Q_DECLARE_METATYPE(std::shared_ptr<Category>)
+
+DISCOVERCOMMON_EXPORT QDebug operator<<(QDebug dbg, const std::shared_ptr<Category> &category);
