@@ -199,12 +199,11 @@ void FlatpakResource::updateFromAppStream()
     updateFromRef(ref);
 }
 
-QStringList FlatpakResource::categories()
+bool FlatpakResource::hasCategory(const QString &category) const
 {
-    auto cats = m_appdata.categories();
-    if (m_appdata.kind() != AppStream::Component::KindAddon)
-        cats.append(QStringLiteral("Application"));
-    return cats;
+    if (m_appdata.kind() != AppStream::Component::KindAddon && category == QStringLiteral("Application"))
+        return true;
+    return m_appdata.hasCategory(category);
 }
 
 QString FlatpakResource::comment()
@@ -535,7 +534,14 @@ void FlatpakResource::invokeApplication() const
 
 void FlatpakResource::fetchChangelog()
 {
-    Q_EMIT changelogFetched(AppStreamUtils::changelogToHtml(m_appdata));
+    if (m_permissions.isEmpty()) {
+        loadPermissions();
+    }
+    QString changelog = AppStreamUtils::changelogToHtml(m_appdata);
+    if (!m_newPermissions.isEmpty()) {
+        changelog += "<h3>New Permissions</h3>\n<ul>"_L1 + m_newPermissions + "</ul>"_L1;
+    }
+    Q_EMIT changelogFetched(changelog);
 }
 
 void FlatpakResource::fetchScreenshots()
@@ -670,9 +676,11 @@ QUrl FlatpakResource::url() const
 
 QDate FlatpakResource::releaseDate() const
 {
-    if (!m_appdata.releasesPlain().isEmpty()) {
-        auto release = m_appdata.releasesPlain().indexSafe(0).value();
-        return release.timestamp().date();
+    if (const auto releases = m_appdata.releasesPlain(); !releases.isEmpty()) {
+        auto release = releases.indexSafe(0);
+        if (release) {
+            return release->timestamp().date();
+        }
     }
 
     return {};
@@ -806,9 +814,18 @@ QString createHtmlList(const QStringList &itemList)
     return str;
 }
 
+bool FlatpakResource::updateNeedsAttention()
+{
+    if (m_permissions.isEmpty()) {
+        loadPermissions();
+    }
+    return !m_newPermissions.isEmpty();
+}
+
 void FlatpakResource::loadPermissions()
 {
-    QByteArray metaDataBytes = FlatpakRunnables::fetchMetadata(this, nullptr);
+    auto b = qobject_cast<FlatpakBackend *>(backend());
+    QByteArray metaDataBytes = FlatpakRunnables::fetchMetadata(this, b->cancellable());
 
     QTemporaryFile f;
     if (!f.open()) {
@@ -816,8 +833,20 @@ void FlatpakResource::loadPermissions()
     }
     f.write(metaDataBytes);
     f.close();
+    m_permissions = readPermissions(f.fileName());
 
-    KDesktopFile parser(f.fileName());
+    auto currentPermissions = readPermissions(installPath() + "/metadata"_L1);
+    for (const auto &permission : std::as_const(m_permissions)) {
+        if (!currentPermissions.contains(permission)) {
+            m_newPermissions += "<li>"_L1 + i18n("%1: %2", permission.brief(), permission.description()) + "</li>\n"_L1;
+        }
+    }
+}
+
+QVector<FlatpakPermission> FlatpakResource::readPermissions(const QString &file) const
+{
+    QVector<FlatpakPermission> permissions;
+    KDesktopFile parser(file);
 
     QString brief, description;
 
@@ -829,7 +858,7 @@ void FlatpakResource::loadPermissions()
     if (shared.contains("network"_L1)) {
         brief = i18n("Network Access");
         description = i18n("Can access the internet");
-        m_permissions.append(FlatpakPermission(brief, description, u"network-wireless-symbolic"_s));
+        permissions.append(FlatpakPermission(brief, description, u"network-wireless-symbolic"_s));
     }
 
     const QString sockets = contextGroup.readEntry("sockets", QString());
@@ -838,64 +867,64 @@ void FlatpakResource::loadPermissions()
 
     if (sockets.contains("pulseaudio"_L1) || filesystems.contains("xdg-run/pipewire-0"_L1)) {
         brief = i18n("Sound system access");
-        description = i18n("Can play audio");
-        m_permissions.append(FlatpakPermission(brief, description, u"audio-speakers-symbolic"_s));
+        description = i18n("Can play and record audio");
+        permissions.append(FlatpakPermission(brief, description, u"audio-speakers-symbolic"_s));
     }
     if (sockets.contains("session-bus"_L1)) {
         brief = i18n("Session Bus Access");
         description = i18n("Can communicate with all other applications and processes run in this user account");
-        m_permissions.append(FlatpakPermission(brief, description, u"security-medium-symbolic"_s));
+        permissions.append(FlatpakPermission(brief, description, u"security-medium-symbolic"_s));
         fullSessionBusAccess = true;
     }
     if (sockets.contains("system-bus"_L1)) {
         brief = i18n("System Bus Access");
         description = i18n("Can communicate with all other applications and processes on the system");
-        m_permissions.append(FlatpakPermission(brief, description, u"security-medium-symbolic"_s));
+        permissions.append(FlatpakPermission(brief, description, u"security-medium-symbolic"_s));
         fullSystemBusAccess = true;
     }
     if (sockets.contains("ssh-auth"_L1)) {
         brief = i18n("Remote Login Access");
         description = i18n("Can initiate remote login requests using the SSH protocol");
-        m_permissions.append(FlatpakPermission(brief, description, u"x-shape-connection-symbolic"_s));
+        permissions.append(FlatpakPermission(brief, description, u"x-shape-connection-symbolic"_s));
     }
     if (sockets.contains("pcsc"_L1)) {
         brief = i18n("Smart Card Access");
         description = i18n("Can integrate and communicate with smart cards");
-        m_permissions.append(FlatpakPermission(brief, description, u"auth-sim-symbolic"_s));
+        permissions.append(FlatpakPermission(brief, description, u"auth-sim-symbolic"_s));
     }
     if (sockets.contains("cups"_L1)) {
         brief = i18n("Printer Access");
         description = i18n("Can integrate and communicate with printers");
-        m_permissions.append(FlatpakPermission(brief, description, u"printer-symbolic"_s));
+        permissions.append(FlatpakPermission(brief, description, u"printer-symbolic"_s));
     }
     if (sockets.contains("gpg-agent"_L1)) {
         brief = i18n("GPG Agent");
         description = i18n("Allows access to the GPG cryptography service, generally used for signing and reading signed documents");
-        m_permissions.append(FlatpakPermission(brief, description, u"document-edit-sign-encrypt"_s));
+        permissions.append(FlatpakPermission(brief, description, u"document-edit-sign-encrypt"_s));
     }
 
     const QString features = contextGroup.readEntry("features", QString());
     if (features.contains("bluetooth"_L1)) {
         brief = i18n("Bluetooth Access");
         description = i18n("Can integrate and communicate with Bluetooth devices");
-        m_permissions.append(FlatpakPermission(brief, description, u"network-bluetooth-symbolic"_s));
+        permissions.append(FlatpakPermission(brief, description, u"network-bluetooth-symbolic"_s));
     }
     if (features.contains("devel"_L1)) {
         brief = i18n("Low-Level System Access");
         description = i18n("Can make low-level system calls (e.g. ptrace)");
-        m_permissions.append(FlatpakPermission(brief, description, u"run-build-symbolic"_s));
+        permissions.append(FlatpakPermission(brief, description, u"run-build-symbolic"_s));
     }
 
     const QString devices = contextGroup.readEntry("devices", QString());
     if (devices.contains("all"_L1)) {
         brief = i18n("Device Access");
         description = i18n("Can communicate with and control built-in or connected hardware devices");
-        m_permissions.append(FlatpakPermission(brief, description, u"device-notifier-symbolic"_s));
+        permissions.append(FlatpakPermission(brief, description, u"device-notifier-symbolic"_s));
     }
     if (devices.contains("kvm"_L1)) {
         brief = i18n("Kernel-based Virtual Machine Access");
         description = i18n("Allows running other operating systems as guests in virtual machines");
-        m_permissions.append(FlatpakPermission(brief, description, u"virt-manager-symbolic"_s));
+        permissions.append(FlatpakPermission(brief, description, u"virt-manager-symbolic"_s));
     }
 
     QStringList homeList, systemList;
@@ -965,7 +994,7 @@ void FlatpakResource::loadPermissions()
         } else {
             description = i18n("Can access files in the following locations in your home folder without asking permission first: %1", appendText);
         }
-        m_permissions.append(FlatpakPermission(brief, description, u"user-home-symbolic"_s));
+        permissions.append(FlatpakPermission(brief, description, u"user-home-symbolic"_s));
     }
     appendText = createHtmlList(systemList);
     if (systemAccess) {
@@ -979,7 +1008,7 @@ void FlatpakResource::loadPermissions()
         } else {
             description = i18n("Can access system files in the following locations without asking permission first: %1", appendText);
         }
-        m_permissions.append(FlatpakPermission(brief, description, u"drive-harddisk-root-symbolic"_s));
+        permissions.append(FlatpakPermission(brief, description, u"drive-harddisk-root-symbolic"_s));
     }
 
     if (!fullSessionBusAccess) {
@@ -990,7 +1019,7 @@ void FlatpakResource::loadPermissions()
             description =
                 i18n("Can communicate with other applications and processes in the same desktop session using the following communication protocols: %1",
                      createHtmlList(busList));
-            m_permissions.append(FlatpakPermission(brief, description, "plugins-symbolic"_L1));
+            permissions.append(FlatpakPermission(brief, description, "plugins-symbolic"_L1));
         }
     }
 
@@ -1001,9 +1030,10 @@ void FlatpakResource::loadPermissions()
             brief = i18n("System Bus Access");
             description =
                 i18n("Can communicate with all applications and system services using the following communication protocols: %1", createHtmlList(busList));
-            m_permissions.append(FlatpakPermission(brief, description, "plugins-symbolic"_L1));
+            permissions.append(FlatpakPermission(brief, description, "plugins-symbolic"_L1));
         }
     }
+    return permissions;
 }
 
 QString FlatpakResource::dataLocation() const
@@ -1085,5 +1115,18 @@ bool FlatpakResource::hasResolvedIcon() const
     return m_icon.has_value();
 }
 
+QString FlatpakResource::verifiedMessage() const
+{
+    const bool flathubVerified = m_appdata.customValue(QStringLiteral("flathub::verification::verified")) == QLatin1String("true");
+    if (flathubVerified) {
+        bool ok;
+        const qint64 time = m_appdata.customValue(QStringLiteral("flathub::verification::timestamp")).toUInt(&ok);
+        return i18n("App Verified on %1 as shipped by its author %2",
+                    KFormat().formatRelativeDateTime(QDateTime::fromSecsSinceEpoch(time), QLocale::ShortFormat),
+                    author());
+    }
+    return {};
+}
+
 #include "FlatpakResource.moc"
 #include "moc_FlatpakResource.cpp"
